@@ -11,6 +11,11 @@ if sys.maxsize > 2 ** 32:
             self.assertEqual(LocalAuthentication.kLAPolicyDeviceOwnerAuthentication, 2)
             self.assertEqual(LocalAuthentication.kLAOptionUserFallback, 1)
             self.assertEqual(LocalAuthentication.kLAOptionAuthenticationReason, 2)
+
+            self.assertEqual(LocalAuthentication.kLACredentialTypePasscode, -1)
+            self.assertEqual(LocalAuthentication.kLACredentialTypePassphrase, -2)
+            self.assertEqual(LocalAuthentication.kLACredentialCTKPIN, -3)
+
             self.assertEqual(LocalAuthentication.kLAErrorAuthenticationFailed, -1)
             self.assertEqual(LocalAuthentication.kLAErrorUserCancel, -2)
             self.assertEqual(LocalAuthentication.kLAErrorUserFallback, -3)
